@@ -46,33 +46,38 @@ def lazy_import(func):
     return _LazyImport(func.func_name,func,namespace)
 
 
+
 class _LazyImport(object):
     """Class representing a lazy import."""
 
     def __init__(self,name,loader,namespace=None):
+        self._esky_lazy_target = _LazyImport
         self._esky_lazy_name = name
         self._esky_lazy_loader = loader
         self._esky_lazy_namespace = namespace
-        self._esky_lazy_target_ = None
 
-    @property
-    def _esky_lazy_target(self):
-        """Property giving the target object for proxying."""
-        if self._esky_lazy_target_ is None:
-            self._esky_lazy_target_ = self._esky_lazy_loader()
+    def _esky_lazy_load(self):
+        if self._esky_lazy_target is _LazyImport:
+            self._esky_lazy_target = self._esky_lazy_loader()
             ns = self._esky_lazy_namespace
             if ns is not None:
                 try: 
                     if ns[self._esky_lazy_name] is self:
-                        ns[self._esky_lazy_name] = self._esky_lazy_target_
+                        ns[self._esky_lazy_name] = self._esky_lazy_target
                 except KeyError:
                     pass
-        return self._esky_lazy_target_
 
-    def __getattr__(self,attr):
-        return getattr(self._esky_lazy_target,attr)
+    def __getattribute__(self,attr):
+        try:
+            return object.__getattribute__(self,attr)
+        except AttributeError:
+            if self._esky_lazy_target is _LazyImport:
+                self._esky_lazy_load()
+            return getattr(self._esky_lazy_target,attr)
 
     def __nonzero__(self):
+        if self._esky_lazy_target is _LazyImport:
+            self._esky_lazy_load()
         return bool(self._esky_lazy_target)
 
 
